﻿using System;

/// <summary>
/// Custom Function ConcatRangeWithSeparator to replace the one in the Macro-enabled Workbook
/// </summary>
public class ConcatRangeWithSeparator : SpreadsheetGear.CustomFunctions.Function
{
    // Set to the one and only instance of this function
    public static readonly ConcatRangeWithSeparator ConcatRangeWithSeparatorSingleton = new ConcatRangeWithSeparator();
    public override void Evaluate(
        SpreadsheetGear.CustomFunctions.IArguments arguments,
        SpreadsheetGear.CustomFunctions.IValue result)
    {
        String retVal = "";
        String sep = arguments.GetText(1);
        int rows, cols;
        arguments.GetArrayDimensions(0, out rows, out cols);
        for (int r = 0; r < rows; r++)
        {
            for (int c = 0; c < cols; c++)
            {
                if (!arguments.GetArrayValue(0, r, c).IsEmpty)
                {
                    if (retVal.Length > 0)
                        retVal += sep + arguments.GetArrayValue(0, r, c).Text;
                    else
                        retVal = arguments.GetArrayValue(0, r, c).Text;
                }
            }
        }
        result.Text = retVal;
    }
    // Singleton class - so make the constructor private.
    private ConcatRangeWithSeparator()
        : base(
            // The name of the custom function.
        "ConcatRangeWithSeparator",
            // For a given set of inputs, this function always returns the same value.
        SpreadsheetGear.CustomFunctions.Volatility.Invariant,
            // This function returns a string.
        SpreadsheetGear.CustomFunctions.ValueType.Text)
    {
    }
}
